pub enum DataRequest {
Table(TableId),
Columns(TableId, Vec<ColumnId>),
Tuple(Vec<RecordId>),
}Expand description
DataRequest specifies the requests that the execution engine might issue to
the storage node.
Currently we assume the execution engine only requests the whole table/column. We may
add std::ops::RangeBounds later to support range query from the execution engine.
Variants
Table(TableId)
Requests a whole table from the underlying storage.
Columns(TableId, Vec<ColumnId>)
Requests one or more columns from the underlying storage.
Tuple(Vec<RecordId>)
Requests one or more tuples from the underlying storage. FIXME: Do we really need this?