Trait StorageClient

pub trait StorageClient:
    Send
    + Sync
    + 'static {
    // Required methods
    fn request_data<'life0, 'async_trait>(
        &'life0 mut self,
        request: StorageRequest,
    ) -> Pin<Box<dyn Future<Output = Result<Receiver<RecordBatch>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn request_data_sync<'life0, 'async_trait>(
        &'life0 mut self,
        request: StorageRequest,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<RecordBatch>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
StorageClient provides the interface for the execution engine to query data from the storage node. It resolves the physical location of the tables/columns/tuples by querying the catalog node, and then sends the request to the storage node to get the data from the underlying storage.

Required Methods

fn request_data<'life0, 'async_trait>( &'life0 mut self, request: StorageRequest, ) -> Pin<Box<dyn Future<Output = Result<Receiver<RecordBatch>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Returns the requested data as a stream.

fn request_data_sync<'life0, 'async_trait>( &'life0 mut self, request: StorageRequest, ) -> Pin<Box<dyn Future<Output = Result<Vec<RecordBatch>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Returns all the requested data as a whole.

Implementors