Type Alias TableId

pub type TableId = u64;
Id types for table, column, and record. Need to be consistent among all components (e.g. execution engine). We don’t want to make any type generic here just for the id, so we simply define them here. Might refine later.